/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TConfigSalary;
import com.yifu.cloud.plus.v1.yifu.salary.service.TConfigSalaryService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TConfigSalarySearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 项目基础薪酬配置-薪资配置2
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tconfigsalary")
@Tag(name = "项目基础薪酬配置-薪资配置2管理")
public class TConfigSalaryController {

	private final TConfigSalaryService tConfigSalaryService;


	/**
	 * 简单分页查询
	 *
	 * @param page          分页对象
	 * @param tConfigSalary 项目基础薪酬配置-薪资配置2
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TConfigSalary>> getTConfigSalaryPage(Page<TConfigSalary> page, TConfigSalarySearchVo tConfigSalary) {
		return new R<>(tConfigSalaryService.getTConfigSalaryPage(page, tConfigSalary));
	}

	/**
	 * 不分页查询
	 *
	 * @param tConfigSalary 项目基础薪酬配置-薪资配置2
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_tconfigsalary_get')" )
	public R<List<TConfigSalary>> getTConfigSalaryNoPage(@RequestBody TConfigSalarySearchVo tConfigSalary) {
		return R.ok(tConfigSalaryService.noPageDiy(tConfigSalary));
	}

	/**
	 * 通过id查询项目基础薪酬配置-薪资配置2
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tconfigsalary_get')")
	@GetMapping("/{id}")
	public R<TConfigSalary> getById(@PathVariable("id") String id) {
		return R.ok(tConfigSalaryService.getById(id));
	}

	/**
	 * 新增项目基础薪酬配置-薪资配置2
	 *
	 * @param tConfigSalary 项目基础薪酬配置-薪资配置2
	 * @return R
	 */
	@Operation(summary = "新增项目基础薪酬配置-薪资配置2", description = "新增项目基础薪酬配置-薪资配置2：hasPermission('salary_tconfigsalary_add')")
	@SysLog("新增项目基础薪酬配置-薪资配置2")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tconfigsalary_add')")
	public R<Boolean> save(@RequestBody TConfigSalary tConfigSalary) {
		return R.ok(tConfigSalaryService.save(tConfigSalary));
	}

	/**
	 * 修改项目基础薪酬配置-薪资配置2
	 *
	 * @param tConfigSalary 项目基础薪酬配置-薪资配置2
	 * @return R
	 */
	@Operation(summary = "修改项目基础薪酬配置-薪资配置2", description = "修改项目基础薪酬配置-薪资配置2：hasPermission('salary_tconfigsalary_edit')")
	@SysLog("修改项目基础薪酬配置-薪资配置2")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tconfigsalary_edit')")
	public R<Boolean> updateById(@RequestBody TConfigSalary tConfigSalary) {
		return R.ok(tConfigSalaryService.updateById(tConfigSalary));
	}

	/**
	 * 通过id删除项目基础薪酬配置-薪资配置2
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除项目基础薪酬配置-薪资配置2", description = "通过id删除项目基础薪酬配置-薪资配置2：hasPermission('salary_tconfigsalary_del')")
	@SysLog("通过id删除项目基础薪酬配置-薪资配置2")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tconfigsalary_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tConfigSalaryService.removeById(id));
	}

}
