/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TMinSalary;
import com.yifu.cloud.plus.v1.yifu.salary.service.TMinSalaryService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TMinSalarySearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 最低工资配置-薪资配置4
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tminsalary")
@Tag(name = "最低工资配置-薪资配置4管理")
public class TMinSalaryController {

	private final TMinSalaryService tMinSalaryService;


	/**
	 * 简单分页查询
	 *
	 * @param page       分页对象
	 * @param tMinSalary 最低工资配置-薪资配置4
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TMinSalary>> getTMinSalaryPage(Page<TMinSalary> page, TMinSalarySearchVo tMinSalary) {
		return new R<>(tMinSalaryService.getTMinSalaryPage(page, tMinSalary));
	}

	/**
	 * 不分页查询
	 *
	 * @param tMinSalary 最低工资配置-薪资配置4
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_tminsalary_get')" )
	public R<List<TMinSalary>> getTMinSalaryNoPage(@RequestBody TMinSalarySearchVo tMinSalary) {
		return R.ok(tMinSalaryService.noPageDiy(tMinSalary));
	}

	/**
	 * 通过id查询最低工资配置-薪资配置4
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tminsalary_get')")
	@GetMapping("/{id}")
	public R<TMinSalary> getById(@PathVariable("id") String id) {
		return R.ok(tMinSalaryService.getById(id));
	}

	/**
	 * 新增最低工资配置-薪资配置4
	 *
	 * @param tMinSalary 最低工资配置-薪资配置4
	 * @return R
	 */
	@Operation(summary = "新增最低工资配置-薪资配置4", description = "新增最低工资配置-薪资配置4：hasPermission('salary_tminsalary_add')")
	@SysLog("新增最低工资配置-薪资配置4")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tminsalary_add')")
	public R<Boolean> save(@RequestBody TMinSalary tMinSalary) {
		return R.ok(tMinSalaryService.save(tMinSalary));
	}

	/**
	 * 修改最低工资配置-薪资配置4
	 *
	 * @param tMinSalary 最低工资配置-薪资配置4
	 * @return R
	 */
	@Operation(summary = "修改最低工资配置-薪资配置4", description = "修改最低工资配置-薪资配置4：hasPermission('salary_tminsalary_edit')")
	@SysLog("修改最低工资配置-薪资配置4")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tminsalary_edit')")
	public R<Boolean> updateById(@RequestBody TMinSalary tMinSalary) {
		return R.ok(tMinSalaryService.updateById(tMinSalary));
	}

	/**
	 * 通过id删除最低工资配置-薪资配置4
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除最低工资配置-薪资配置4", description = "通过id删除最低工资配置-薪资配置4：hasPermission('salary_tminsalary_del')")
	@SysLog("通过id删除最低工资配置-薪资配置4")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tminsalary_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tMinSalaryService.removeById(id));
	}

}
