/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TSalaryConfigStandard;
import com.yifu.cloud.plus.v1.yifu.salary.service.TSalaryConfigStandardService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TSalaryConfigStandardSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 工资报表配置-薪资配置6
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tsalaryconfigstandard")
@Tag(name = "工资报表配置-薪资配置6管理")
public class TSalaryConfigStandardController {

	private final TSalaryConfigStandardService tSalaryConfigStandardService;


	/**
	 * 简单分页查询
	 *
	 * @param page                  分页对象
	 * @param tSalaryConfigStandard 工资报表配置-薪资配置6
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TSalaryConfigStandard>> getTSalaryConfigStandardPage(Page<TSalaryConfigStandard> page, TSalaryConfigStandardSearchVo tSalaryConfigStandard) {
		return new R<>(tSalaryConfigStandardService.getTSalaryConfigStandardPage(page, tSalaryConfigStandard));
	}

	/**
	 * 不分页查询
	 *
	 * @param tSalaryConfigStandard 工资报表配置-薪资配置6
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_tsalaryconfigstandard_get')" )
	public R<List<TSalaryConfigStandard>> getTSalaryConfigStandardNoPage(@RequestBody TSalaryConfigStandardSearchVo tSalaryConfigStandard) {
		return R.ok(tSalaryConfigStandardService.noPageDiy(tSalaryConfigStandard));
	}

	/**
	 * 通过id查询工资报表配置-薪资配置6
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tsalaryconfigstandard_get')")
	@GetMapping("/{id}")
	public R<TSalaryConfigStandard> getById(@PathVariable("id") String id) {
		return R.ok(tSalaryConfigStandardService.getById(id));
	}

	/**
	 * 新增工资报表配置-薪资配置6
	 *
	 * @param tSalaryConfigStandard 工资报表配置-薪资配置6
	 * @return R
	 */
	@Operation(summary = "新增工资报表配置-薪资配置6", description = "新增工资报表配置-薪资配置6：hasPermission('salary_tsalaryconfigstandard_add')")
	@SysLog("新增工资报表配置-薪资配置6")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalaryconfigstandard_add')")
	public R<Boolean> save(@RequestBody TSalaryConfigStandard tSalaryConfigStandard) {
		return R.ok(tSalaryConfigStandardService.save(tSalaryConfigStandard));
	}

	/**
	 * 修改工资报表配置-薪资配置6
	 *
	 * @param tSalaryConfigStandard 工资报表配置-薪资配置6
	 * @return R
	 */
	@Operation(summary = "修改工资报表配置-薪资配置6", description = "修改工资报表配置-薪资配置6：hasPermission('salary_tsalaryconfigstandard_edit')")
	@SysLog("修改工资报表配置-薪资配置6")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalaryconfigstandard_edit')")
	public R<Boolean> updateById(@RequestBody TSalaryConfigStandard tSalaryConfigStandard) {
		return R.ok(tSalaryConfigStandardService.updateById(tSalaryConfigStandard));
	}

	/**
	 * 通过id删除工资报表配置-薪资配置6
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除工资报表配置-薪资配置6", description = "通过id删除工资报表配置-薪资配置6：hasPermission('salary_tsalaryconfigstandard_del')")
	@SysLog("通过id删除工资报表配置-薪资配置6")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tsalaryconfigstandard_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tSalaryConfigStandardService.removeById(id));
	}

}
