/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TSalaryTaxConfig;
import com.yifu.cloud.plus.v1.yifu.salary.service.TSalaryTaxConfigService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TSalaryTaxConfigSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 所得税配置-薪资配置3
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tsalarytaxconfig")
@Tag(name = "所得税配置-薪资配置3管理")
public class TSalaryTaxConfigController {

	private final TSalaryTaxConfigService tSalaryTaxConfigService;


	/**
	 * 简单分页查询
	 *
	 * @param page             分页对象
	 * @param tSalaryTaxConfig 所得税配置-薪资配置3
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TSalaryTaxConfig>> getTSalaryTaxConfigPage(Page<TSalaryTaxConfig> page, TSalaryTaxConfigSearchVo tSalaryTaxConfig) {
		return new R<>(tSalaryTaxConfigService.getTSalaryTaxConfigPage(page, tSalaryTaxConfig));
	}

	/**
	 * 通过id查询所得税配置-薪资配置3
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tsalarytaxconfig_get')")
	@GetMapping("/{id}")
	public R<TSalaryTaxConfig> getById(@PathVariable("id") String id) {
		return R.ok(tSalaryTaxConfigService.getById(id));
	}

	/**
	 * 新增所得税配置-薪资配置3
	 *
	 * @param tSalaryTaxConfig 所得税配置-薪资配置3
	 * @return R
	 */
	@Operation(summary = "新增所得税配置-薪资配置3", description = "新增所得税配置-薪资配置3：hasPermission('salary_tsalarytaxconfig_add')")
	@SysLog("新增所得税配置-薪资配置3")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalarytaxconfig_add')")
	public R<Boolean> save(@RequestBody TSalaryTaxConfig tSalaryTaxConfig) {
		return R.ok(tSalaryTaxConfigService.save(tSalaryTaxConfig));
	}

	/**
	 * 修改所得税配置-薪资配置3
	 *
	 * @param tSalaryTaxConfig 所得税配置-薪资配置3
	 * @return R
	 */
	@Operation(summary = "修改所得税配置-薪资配置3", description = "修改所得税配置-薪资配置3：hasPermission('salary_tsalarytaxconfig_edit')")
	@SysLog("修改所得税配置-薪资配置3")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalarytaxconfig_edit')")
	public R<Boolean> updateById(@RequestBody TSalaryTaxConfig tSalaryTaxConfig) {
		return R.ok(tSalaryTaxConfigService.updateById(tSalaryTaxConfig));
	}

	/**
	 * 通过id删除所得税配置-薪资配置3
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除所得税配置-薪资配置3", description = "通过id删除所得税配置-薪资配置3：hasPermission('salary_tsalarytaxconfig_del')")
	@SysLog("通过id删除所得税配置-薪资配置3")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tsalarytaxconfig_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tSalaryTaxConfigService.removeById(id));
	}

}
