/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.ErrorMessage;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TSpecialDeducationSum;
import com.yifu.cloud.plus.v1.yifu.salary.service.TSpecialDeducationSumService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TSpecialDeducationSumSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;


/**
 * 专项扣除配置表-薪资配置5
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tspecialdeducationsum")
@Tag(name = "专项扣除配置表-薪资配置5管理")
public class TSpecialDeducationSumController {

	private final TSpecialDeducationSumService tSpecialDeducationSumService;


	/**
	 * 简单分页查询
	 *
	 * @param page                  分页对象
	 * @param tSpecialDeducationSum 专项扣除配置表-薪资配置5
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TSpecialDeducationSum>> getTSpecialDeducationSumPage(Page<TSpecialDeducationSum> page, TSpecialDeducationSumSearchVo tSpecialDeducationSum) {
		return new R<>(tSpecialDeducationSumService.getTSpecialDeducationSumPage(page, tSpecialDeducationSum));
	}

	/**
	 * 不分页查询
	 *
	 * @param tSpecialDeducationSum 专项扣除配置表-薪资配置5
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_tspecialdeducationsum_get')" )
	public R<List<TSpecialDeducationSum>> getTSpecialDeducationSumNoPage(@RequestBody TSpecialDeducationSumSearchVo tSpecialDeducationSum) {
		return R.ok(tSpecialDeducationSumService.noPageDiy(tSpecialDeducationSum));
	}

	/**
	 * 通过id查询专项扣除配置表-薪资配置5
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tspecialdeducationsum_get')")
	@GetMapping("/{id}")
	public R<TSpecialDeducationSum> getById(@PathVariable("id") String id) {
		return R.ok(tSpecialDeducationSumService.getById(id));
	}

	/**
	 * 新增专项扣除配置表-薪资配置5
	 *
	 * @param tSpecialDeducationSum 专项扣除配置表-薪资配置5
	 * @return R
	 */
	@Operation(summary = "新增专项扣除配置表-薪资配置5", description = "新增专项扣除配置表-薪资配置5：hasPermission('salary_tspecialdeducationsum_add')")
	@SysLog("新增专项扣除配置表-薪资配置5")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tspecialdeducationsum_add')")
	public R<Boolean> save(@RequestBody TSpecialDeducationSum tSpecialDeducationSum) {
		return R.ok(tSpecialDeducationSumService.save(tSpecialDeducationSum));
	}

	/**
	 * 修改专项扣除配置表-薪资配置5
	 *
	 * @param tSpecialDeducationSum 专项扣除配置表-薪资配置5
	 * @return R
	 */
	@Operation(summary = "修改专项扣除配置表-薪资配置5", description = "修改专项扣除配置表-薪资配置5：hasPermission('salary_tspecialdeducationsum_edit')")
	@SysLog("修改专项扣除配置表-薪资配置5")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tspecialdeducationsum_edit')")
	public R<Boolean> updateById(@RequestBody TSpecialDeducationSum tSpecialDeducationSum) {
		return R.ok(tSpecialDeducationSumService.updateById(tSpecialDeducationSum));
	}

	/**
	 * 通过id删除专项扣除配置表-薪资配置5
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除专项扣除配置表-薪资配置5", description = "通过id删除专项扣除配置表-薪资配置5：hasPermission('salary_tspecialdeducationsum_del')")
	@SysLog("通过id删除专项扣除配置表-薪资配置5")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tspecialdeducationsum_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tSpecialDeducationSumService.removeById(id));
	}

	/**
	 * 专项扣除配置表-薪资配置5 批量导入
	 *
	 * @author hgw
	 * @date 2022-08-05 11:40:14
	 **/
	@SneakyThrows
	@Operation(description = "批量新增专项扣除配置表-薪资配置5 hasPermission('salary_tspecialdeducationsum-batch-import')")
	@SysLog("批量新增专项扣除配置表-薪资配置5")
	@PostMapping("/importListAdd")
	@PreAuthorize("@pms.hasPermission('salary_tspecialdeducationsum-batch-import')")
	public R<List<ErrorMessage>> importListAdd(@RequestBody MultipartFile file) {
		return tSpecialDeducationSumService.importDiy(file.getInputStream());
	}

	/**
	 * 专项扣除配置表-薪资配置5 批量导出
	 *
	 * @author hgw
	 * @date 2022-08-05 11:40:14
	 **/
	@Operation(description = "导出专项扣除配置表-薪资配置5 hasPermission('salary_tspecialdeducationsum-export')")
	@PostMapping("/export")
	@PreAuthorize("@pms.hasPermission('salary_tspecialdeducationsum-export')")
	public void export(HttpServletResponse response, @RequestBody TSpecialDeducationSumSearchVo searchVo) {
		tSpecialDeducationSumService.listExport(response, searchVo);
	}
}
